def us_state_abbr_to_state_name(df, source_data_name):
    df = df
    state_abbr_to_fullname = {
        'al':	'alabama',
        'ak':	'alaska',
        'az':	'arizona',
        'ar':	'arkansas',
        'ca':	'california',
        'co':	'colorado',
        'ct':	'connecticut',
        'de':	'delaware',
        'fl':	'florida',
        'ga':	'georgia',
        'hi':	'hawaii',
        'id':	'idaho',
        'il':	'illinois',
        'in':	'indiana',
        'ia':	'iowa',
        'ks':	'kansas',
        'ky':	'kentucky',
        'la':	'louisiana',
        'me':	'maine',
        'md':	'maryland',
        'ma':	'massachusetts',
        'mi':	'michigan',
        'mn':	'minnesota',
        'ms':	'mississippi',
        'mo':	'missouri',
        'mt':	'montana',
        'ne':	'nebraska',
        'nv':	'nevada',
        'nh':	'new hampshire',
        'nj':	'new jersey',
        'nm':	'new mexico',
        'ny':	'new york',
        'nc':	'north carolina',
        'nd':	'north dakota',
        'oh':	'ohio',
        'ok':	'oklahoma',
        'or':	'oregon',
        'pa':	'pennsylvania',
        'ri':	'rhode island',
        'sc':	'south carolina',
        'sd':	'south dakota',
        'tn':	'tennessee',
        'tx':	'texas',
        'ut':	'utah',
        'vt':	'vermont',
        'va':	'virginia',
        'wa':	'washington',
        'wv':	'west virginia',
        'wi':	'wisconsin',
        'wy':	'wyoming',
        'as': 'american samoa',
        'dc': 'district of columbia',
        'fm': 'federated states of micronesia',
        'gu': 'guam',
        'mh': 'marshall island',
        'mp': 'northern mariana islands',
        'pw': 'palau',
        'pr': 'puerto rico',
        'vi': 'virgin islands'

    }
    df.replace({source_data_name: state_abbr_to_fullname}, inplace=True)
    return df

def us_state_full_name_to_state_abbr(df, source_data_name):
    df = df
    state_fullname_to_abbr = {
        'alabama':  'al',
        'alaska':   'ak',
        'arizona':	'az',
        'arkansas':	'ar',
        'california':	'ca',
        'colorado':	'co',
        'connecticut':	'ct',
        'delaware':	'de',
        'florida':	'fl',
        'georgia':	'ga',
        'hawaii':	'hi',
        'idaho':	'id',
        'illinois':	'il',
        'indiana':	'in',
        'iowa':	'ia',
        'kansas':	'ks',
        'kentucky':	'ky',
        'louisiana':	'la',
        'maine':	'me',
        'maryland':	'md',
        'massachusetts':	'ma',
        'michigan':	'mi',
        'minnesota':	'mn',
        'mississippi':	'ms',
        'missouri':	'mo',
        'montana':	'mt',
        'nebraska':	'ne',
        'nevada':	'nv',
        'new hampshire':	'nh',
        'new jersey':	'nj',
        'new mexico':	'nm',
        'new york':	'ny',
        'north carolina':	'nc',
        'north dakota':	'nd',
        'ohio':	'oh',
        'oklahoma':	'ok',
        'oregon':	'or',
        'pennsylvania':	'pa',
        'rhode island':	'ri',
        'south carolina':	'sc',
        'south dakota':	'sd',
        'tennessee':	'tn',
        'texas':	'tx',
        'utah':	'ut',
        'vermont':	'vt',
        'virginia':	'va',
        'washington':	'wa',
        'west virginia':	'wv',
        'wisconsin':	'wi',
        'wyoming':	'wy',
        'american samoa':	'as',
        'district of columbia': 'dc',
        'federated states of micronesia': 'fm',
        'guam': 'gu',
        'marshall island': 'mh',
        'northern mariana islands': 'mp', 
        'palau': 'pw',
        'puerto rico': 'pr',
        'virgin islands': 'vi' 
    }
    df.replace({source_data_name: state_fullname_to_abbr}, inplace=True)
    return df


def us_state_full_name_to_population(df, source_data_name):
    df = df
    state_full_name_to_population = {
        'california':	'39512223',
        'texas':	'28995881',
        'florida':	'21477737',
        'new york':	'19453561',
        'illinois':	'12671821',
        'pennsylvania':	'12801989',
        'ohio':	'11689100',
        'georgia':	'10617423',
        'north carolina':	'10488084',
        'michigan':	'9986857',
        'new jersey':	'8882190',
        'virginia':	'8535519',
        'washington':	'7614893',
        'arizona':	'7278717',
        'massachusetts':	'6949503',
        'tennessee':	'6833174',
        'indiana':	'6732219',
        'missouri':	'6137428',
        'maryland':	'6045680',
        'wisconsin':	'5822434',
        'colorado':	'5758736',
        'minnesota':	'5639632',
        'south carolina':	'5148714',
        'alabama':	'4903185',
        'louisiana':	'4648794',
        'kentucky':	'4467673',
        'oregon':	'4217737',
        'oklahoma':	'3956971',
        'connecticut':	'3565287',
        'utah':	'3205958',
        'iowa':	'3155070',
        'nevada':	'3080156',
        'arkansas':	'3017825',
        'mississippi':	'2976149',
        'kansas':	'2913314',
        'new mexico':	'2096829',
        'nebraska':	'1934408',
        'west virginia':	'1792147',
        'idaho':	'1787065',
        'hawaii':	'1415872',
        'new hampshire':	'1359711',
        'maine':	'1344212',
        'montana':	'1068778',
        'rhode island':	'1059361',
        'delaware':	'973764',
        'south dakota':	'884659',
        'north dakota':	'762062',
        'alaska':	'731545',
        'district of columbia':	'705749',
        'vermont':	'623989',
        'wyoming':	'578759'
    }
    df.replace({source_data_name: state_full_name_to_population}, inplace=True)
    return df

def us_state_full_name_to_area_rank(df, source_data_name):
    df = df
    state_full_name_to_area_rank = {
        'alaska':	'1',
        'texas':	'2',
        'california':	'3',
        'montana':	'4',
        'new mexico':	'5',
        'arizona':	'6',
        'nevada':	'7',
        'colorado':	'8',
        'oregon':	'9',
        'wyoming':	'10',
        'michigan':	'11',
        'minnesota':	'12',
        'utah':	'13',
        'idaho':	'14',
        'kansas':	'15',
        'nebraska':	'16',
        'south dakota':	'17',
        'washington':	'18',
        'north dakota':	'19',
        'oklahoma':	'20',
        'missouri':	'21',
        'florida':	'22',
        'wisconsin':	'23',
        'georgia':	'24',
        'illinois':	'25',
        'iowa':	'26',
        'new york':	'27',
        'north carolina':	'28',
        'arkansas':	'29',
        'alabama':	'30',
        'louisiana':	'31',
        'mississippi':	'32',
        'pennsylvania':	'33',
        'ohio':	'34',
        'virginia':	'35',
        'tennessee':	'36',
        'kentucky':	'37',
        'indiana':	'38',
        'maine':	'39',
        'south carolina':	'40',
        'west virginia':	'41',
        'maryland':	'42',
        'hawaii':	'43',
        'massachusetts':	'44',
        'vermont':	'45',
        'new hampshire':	'46',
        'new jersey':	'47',
        'connecticut':	'48',
        'delaware':	'49',
        'rhode island':	'50'
    }
    df.replace({source_data_name: state_full_name_to_area_rank}, inplace=True)
    return df

def us_state_full_name_to_capital_city(df, source_data_name):
    df = df
    state_fullname_to_capital_city_name = {
        'alabama':	'montgomery',
        'alaska':	'juneau',
        'arizona':	'phoenix',
        'arkansas':	'little Rock',
        'california':	'sacramento',
        'colorado':	'denver',
        'connecticut':	'hartford',
        'delaware':	'dover',
        'florida':	'tallahassee',
        'georgia':	'atlanta',
        'hawaii':	'honolulu',
        'idaho':	'boise',
        'illinois':	'springfield',
        'indiana':	'indianapolis',
        'iowa':	'des Moines',
        'kansas':	'topeka',
        'kentucky':	'frankfort',
        'louisiana':	'baton Rouge',
        'maine':	'augusta',
        'maryland':	'annapolis',
        'massachusetts':	'boston',
        'michigan':	'lansing',
        'minnesota':	'saint Paul',
        'mississippi':	'jackson',
        'missouri':	'jefferson City',
        'montana':	'helena',
        'nebraska':	'lincoln',
        'nevada':	'carson City',
        'new Hampshire':	'concord',
        'new Jersey':	'trenton',
        'new Mexico':	'santa Fe',
        'new York':	'albany',
        'north Carolina':	'raleigh',
        'north Dakota':	'bismarck',
        'ohio':	'columbus',
        'oklahoma':	'oklahoma city',
        'oregon':	'salem',
        'pennsylvania':	'harrisburg',
        'rhode Island':	'providence',
        'south Carolina':	'columbia',
        'south Dakota':	'pierre',
        'tennessee':	'nashville',
        'texas':	'austin',
        'utah':	'salt lake city',
        'vermont':	'montpelier',
        'virginia':	'richmond',
        'washington':	'olympia',
        'west Virginia':	'charleston',
        'wisconsin':	'madison',
        'wyoming':	'cheyenne'
        #TODO: add special teritorries
    }
    df.replace({source_data_name: state_fullname_to_capital_city_name}, inplace=True)
    return df

def us_capital_city_population_2019(df, source_data_name):
    df = df
    us_capital_city_population_2019 = {
        'montgomery':	'198525',
        'juneau':	'32113',
        'phoenix':	'1680992',
        'little rock':	'197312',
        'sacramento':	'513624',
        'denver':	'727211',
        'hartford':	'122105',
        'dover':	'38079',
        'tallahassee':	'194500',
        'atlanta':	'506811',
        'honolulu':	'345064',
        'boise':	'228959',
        'springfield':	'114230',
        'indianapolis':	'876384',
        'des moines':	'214237',
        'topeka':	'125310',
        'frankfort':	'27679',
        'baton rouge':	'220236',
        'augusta':	'18681',
        'annapolis':	'39174',
        'boston':	'692600',
        'lansing':	'118210',
        'saint paul':	'308096',
        'jackson':	'160628',
        'jefferson city':	'42838',
        'helena':	'32315',
        'lincoln':	'289102',
        'carson city':	'55916',
        'concord':	'43627',
        'trenton':	'83203',
        'santa fe':	'84683',
        'albany':	'96460',
        'raleigh':	'474069',
        'bismarck':	'73529',
        'columbus':	'898553',
        'oklahoma city':	'655057',
        'salem':	'174365',
        'harrisburg':	'49528',
        'providence':	'179883',
        'columbia':	'131674',
        'pierre':	'13646',
        'nashville':	'670820',
        'austin':	'978908',
        'salt lake city':	'200567',
        'montpelier':	'7855',
        'richmond':	'230436',
        'olympia':	'46478',
        'charleston':	'46536',
        'madison':	'259680',
        'cheyenne':	'64235'
    }
    df.replace({source_data_name: us_capital_city_population_2019}, inplace=True)
    return df

def us_capital_city_population_2019_msa(df, source_data_name):
    df = df
    us_capital_city_population_2019_msa = {
        'montgomery':	'373290',
        'juneau':	'32113',
        'phoenix':	'4948203',
        'little rock':	'742384',
        'sacramento':	'2363730',
        'denver':	'2967239',
        'hartford':	'1204877',
        'dover':	'180786',
        'tallahassee':	'387227',
        'atlanta':	'6020364',
        'honolulu':	'974563',
        'boise':	'749202',
        'springfield':	'206868',
        'indianapolis':	'2074537',
        'des moines':	'699292',
        'topeka':	'231969',
        'frankfort':	'73663',
        'baton rouge':	'854884',
        'augusta':	'122302',
        'annapolis':	'2800053',
        'boston':	'4873019',
        'lansing':	'550391',
        'saint paul':	'3654908',
        'jackson':	'594806',
        'jefferson city':	'151235',
        'helena':	'77414',
        'lincoln':	'336374',
        'carson city':	'55916',
        'concord':	'151391',
        'trenton':	'367430',
        'santa fe':	'150358',
        'albany':	'880381',
        'raleigh':	'1390785',
        'bismarck':	'128949',
        'columbus':	'2122271',
        'oklahoma City':	'1408950',
        'salem':	'433903',
        'harrisburg':	'577941',
        'providence':	'1624578',
        'columbia':	'838433',
        'pierre':	'20672',
        'nashville':	'1934317',
        'austin':	'2227083',
        'salt lake city':	'1232696',
        'montpelier':	'7855',
        'richmond':	'1291900',
        'olympia':	'290536',
        'charleston':	'257074',
        'madison':	'664865',
        'cheyenne':	'99500'
    }
    df.replace({source_data_name: us_capital_city_population_2019_msa}, inplace=True)
    return df

def us_capital_city_population_2019_csa(df, source_data_name):
    df = df
    us_capital_city_population_2019_csa = {
        'montgomery':	'461516',
        'juneau':	'32113',
        'phoenix':	'5002221',
        'little rock':	'908941',
        'sacramento':	'2639124',
        'denver':	'3617927',
        'hartford':	'1470083',
        'dover':	'7209620',
        'tallahassee':	'387227',
        'atlanta':	'6853392',
        'honolulu':	'974563',
        'boise':	'831235',
        'springfield':	'306399',
        'indianapolis':	'2457286',
        'des moines':	'877991',
        'topeka':	'231969',
        'frankfort':	'745033',
        'baton rouge':	'854884',
        'augusta':	'122302',
        'annapolis':	'9814928',
        'boston':	'8287710',
        'lansing':	'550391',
        'saint paul':	'4027861',
        'jackson':	'674340',
        'jefferson city':	'151235',
        'helena':	'77414',
        'lincoln':	'357887',
        'carson city':	'637973',
        'concord':	'8287710',
        'trenton':	'22589036',
        'santa fe':	'1158464',
        'albany':	'1167594',
        'raleigh':	'2079687',
        'bismarck':	'128949',
        'columbus':	'2525639',
        'oklahoma city':	'1481542',
        'salem':	'3259710',
        'harrisburg':	'1271801',
        'providence':	'8287710',
        'columbia':	'963048',
        'pierre':	'20672',
        'nashville':	'2062547',
        'austin':	'2227083',
        'salt lake city':	'2641048',
        'montpelier':	'7855',
        'richmond':	'1291900',
        'olympia':	'4903675',
        'charleston':	'776694',
        'madison':	'892661',
        'cheyenne':	'99500'
    }
    df.replace({source_data_name: us_capital_city_population_2019_csa}, inplace=True)
    return df

def us_state_total_area_rank(df, source_data_name):
    df = df
    us_state_total_area_rank = {
        'alaska': 	'1',
        'texas': 	'2',
        'california': 	'3',
        'montana': 	'4',
        'new mexico': 	'5',
        'arizona': 	'6',
        'nevada': 	'7',
        'colorado': 	'8',
        'oregon': 	'9',
        'wyoming': 	'10',
        'michigan': 	'11',
        'minnesota': 	'12',
        'utah': 	'13',
        'idaho': 	'14',
        'kansas': 	'15',
        'nebraska': 	'16',
        'south dakota': 	'17',
        'washington': 	'18',
        'north dakota': 	'19',
        'oklahoma': 	'20',
        'missouri': 	'21',
        'florida': 	'22',
        'wisconsin': 	'23',
        'georgia': 	'24',
        'illinois': 	'25',
        'iowa': 	'26',
        'new york': 	'27',
        'north carolina': 	'28',
        'arkansas': 	'29',
        'alabama': 	'30',
        'louisiana': 	'31',
        'mississippi': 	'32',
        'pennsylvania': 	'33',
        'ohio': 	'34',
        'virginia': 	'35',
        'tennessee': 	'36',
        'kentucky': 	'37',
        'indiana': 	'38',
        'maine': 	'39',
        'south carolina': 	'40',
        'west virginia': 	'41',
        'maryland': 	'42',
        'hawaii': 	'43',
        'massachusetts': 	'44',
        'vermont': 	'45',
        'new hampshire': 	'46',
        'new jersey': 	'47',
        'connecticut': 	'48',
        'delaware': 	'49',
        'rhode island': 	'50'
    }
    df.replace({source_data_name: us_state_total_area_rank}, inplace=True)
    return df

def us_state_total_area(df, source_data_name):
    df = df
    us_state_total_area = {
        'alaska': 	'1723337',
        'texas': 	'695662',
        'california': 	'423967',
        'montana': 	'380831',
        'new mexico': 	'314917',
        'arizona': 	'295234',
        'nevada': 	'286380',
        'colorado': 	'269601',
        'oregon': 	'254799',
        'wyoming': 	'253335',
        'michigan': 	'250487',
        'minnesota': 	'225163',
        'utah': 	'219882',
        'idaho': 	'216443',
        'kansas': 	'213100',
        'nebraska': 	'200330',
        'south dakota': 	'199729',
        'washington': 	'184661',
        'north dakota': 	'183108',
        'oklahoma': 	'181037',
        'missouri': 	'180540',
        'florida': 	'170312',
        'wisconsin': 	'169635',
        'georgia': 	'153910',
        'illinois': 	'149995',
        'iowa': 	'145746',
        'new york': 	'141297',
        'north carolina': 	'139391',
        'arkansas': 	'137732',
        'alabama': 	'135767',
        'louisiana': 	'135659',
        'mississippi': 	'125438',
        'pennsylvania': 	'119280',
        'ohio': 	'116098',
        'virginia': 	'110787',
        'tennessee': 	'109153',
        'kentucky': 	'104656',
        'indiana': 	'94326',
        'maine': 	'91633',
        'south carolina': 	'82933',
        'west virginia': 	'62756',
        'maryland': 	'32131',
        'hawaii': 	'28313',
        'massachusetts': 	'27336',
        'vermont': 	'24906',
        'new hampshire': 	'24214',
        'new jersey': 	'22591',
        'connecticut': 	'14357',
        'delaware': 	'6446',
        'rhode island': 	'4001'
    }
    df.replace({source_data_name: us_state_total_area}, inplace=True)
    return df

def us_state_land_area_rank(df, source_data_name):
    df = df
    us_state_land_area_rank = {
        'alaska': 	'1',
        'texas': 	'2',
        'california': 	'3',
        'montana': 	'4',
        'new mexico': 	'5',
        'arizona': 	'6',
        'nevada': 	'7',
        'colorado': 	'8',
        'oregon': 	'10',
        'wyoming': 	'9',
        'michigan': 	'22',
        'minnesota': 	'14',
        'utah': 	'12',
        'idaho': 	'11',
        'kansas': 	'13',
        'nebraska': 	'15',
        'south dakota': 	'16',
        'washington': 	'20',
        'north dakota': 	'17',
        'oklahoma': 	'19',
        'missouri': 	'18',
        'florida': 	'26',
        'wisconsin': 	'25',
        'georgia': 	'21',
        'illinois': 	'24',
        'iowa': 	'23',
        'new york': 	'30',
        'north carolina': 	'29',
        'arkansas': 	'27',
        'alabama': 	'28',
        'louisiana': 	'33',
        'mississippi': 	'31',
        'pennsylvania': 	'32',
        'ohio': 	'35',
        'virginia': 	'36',
        'tennessee': 	'34',
        'kentucky': 	'37',
        'indiana': 	'38',
        'maine': 	'39',
        'south carolina': 	'40',
        'west virginia': 	'41',
        'maryland': 	'42',
        'hawaii': 	'47',
        'massachusetts': 	'45',
        'vermont': 	'43',
        'new hampshire': 	'44',
        'new jersey': 	'46',
        'connecticut': 	'48',
        'delaware': 	'49',
        'rhode island': 	'50'
    }
    df.replace({source_data_name: us_state_land_area_rank}, inplace=True)
    return df

def us_state_land_area(df, source_data_name):
    df = df
    us_state_land_area = {
        'alaska': 	'1477953',
        'texas': 	'676587',
        'california': 	'403466',
        'montana': 	'376962',
        'new mexico': 	'314161',
        'arizona': 	'294207',
        'nevada': 	'284332',
        'colorado': 	'268431',
        'oregon': 	'248608',
        'wyoming': 	'251470',
        'michigan': 	'146435',
        'minnesota': 	'206232',
        'utah': 	'212818',
        'idaho': 	'214045',
        'kansas': 	'211754',
        'nebraska': 	'198974',
        'south dakota': 	'196350',
        'washington': 	'172119',
        'north dakota': 	'178711',
        'oklahoma': 	'177660',
        'missouri': 	'178040',
        'florida': 	'138887',
        'wisconsin': 	'140268',
        'georgia': 	'148959',
        'illinois': 	'143793',
        'iowa': 	'144669',
        'new york': 	'122057',
        'north carolina': 	'125920',
        'arkansas': 	'134771',
        'alabama': 	'131171',
        'louisiana': 	'111898',
        'mississippi': 	'121531',
        'pennsylvania': 	'115883',
        'ohio': 	'105829',
        'virginia': 	'102279',
        'tennessee': 	'106798',
        'kentucky': 	'102269',
        'indiana': 	'92789',
        'maine': 	'79883',
        'south carolina': 	'77857',
        'west virginia': 	'62259',
        'maryland': 	'25142',
        'hawaii': 	'16635',
        'massachusetts': 	'20202',
        'vermont': 	'23871',
        'new hampshire': 	'23187',
        'new jersey': 	'19047',
        'connecticut': 	'12542',
        'delaware': 	'5047',
        'rhode island': 	'2678'
    }
    df.replace({source_data_name: us_state_land_area}, inplace=True)
    return df

def us_state_water_area_rank(df, source_data_name):
    df = df
    us_state_water_area_rank = {
        'alaska': 	'1',
        'texas': 	'8',
        'california': 	'6',
        'montana': 	'26',
        'new mexico': 	'49',
        'arizona': 	'48',
        'nevada': 	'36',
        'colorado': 	'44',
        'oregon': 	'20',
        'wyoming': 	'37',
        'michigan': 	'2',
        'minnesota': 	'9',
        'utah': 	'17',
        'idaho': 	'33',
        'kansas': 	'42',
        'nebraska': 	'41',
        'south dakota': 	'29',
        'washington': 	'11',
        'north dakota': 	'24',
        'oklahoma': 	'30',
        'missouri': 	'32',
        'florida': 	'3',
        'wisconsin': 	'4',
        'georgia': 	'22',
        'illinois': 	'19',
        'iowa': 	'45',
        'new york': 	'7',
        'north carolina': 	'10',
        'arkansas': 	'31',
        'alabama': 	'23',
        'louisiana': 	'5',
        'mississippi': 	'25',
        'pennsylvania': 	'28',
        'ohio': 	'14',
        'virginia': 	'15',
        'tennessee': 	'35',
        'kentucky': 	'34',
        'indiana': 	'39',
        'maine': 	'12',
        'south carolina': 	'21',
        'west virginia': 	'50',
        'maryland': 	'18',
        'hawaii': 	'13',
        'massachusetts': 	'16',
        'vermont': 	'46',
        'new hampshire': 	'47',
        'new jersey': 	'27',
        'connecticut': 	'38',
        'delaware': 	'40',
        'rhode island': 	'43'
    }
    df.replace({source_data_name: us_state_water_area_rank}, inplace=True)
    return df

def us_state_water_area(df, source_data_name):
    df = df
    us_state_water_area = {
        'alaska': 	'245384',
        'texas': 	'19075',
        'california': 	'20501',
        'montana': 	'3869',
        'new mexico': 	'757',
        'arizona': 	'1026',
        'nevada': 	'2048',
        'colorado': 	'1170',
        'oregon': 	'6191',
        'wyoming': 	'1864',
        'michigan': 	'104052',
        'minnesota': 	'18930',
        'utah': 	'7064',
        'idaho': 	'2398',
        'kansas': 	'1346',
        'nebraska': 	'1356',
        'south dakota': 	'3379',
        'washington': 	'12542',
        'north dakota': 	'4397',
        'oklahoma': 	'3377',
        'missouri': 	'2501',
        'florida': 	'31424',
        'wisconsin': 	'29367',
        'georgia': 	'4951',
        'illinois': 	'6202',
        'iowa': 	'1077',
        'new york': 	'19240',
        'north carolina': 	'13471',
        'arkansas': 	'2961',
        'alabama': 	'4597',
        'louisiana': 	'23761',
        'mississippi': 	'3907',
        'pennsylvania': 	'3397',
        'ohio': 	'10269',
        'virginia': 	'8508',
        'tennessee': 	'2355',
        'kentucky': 	'2387',
        'indiana': 	'1537',
        'maine': 	'11750',
        'south carolina': 	'5076',
        'west virginia': 	'497',
        'maryland': 	'6990',
        'hawaii': 	'11678',
        'massachusetts': 	'7134',
        'vermont': 	'1035',
        'new hampshire': 	'1027',
        'new jersey': 	'3544',
        'connecticut': 	'1816',
        'delaware': 	'1399',
        'rhode island': 	'1324'
    }
    df.replace({source_data_name: us_state_water_area}, inplace=True)
    return df


import hoopoe
import pytest
import units_conversion
import pandas as pd

def test_us_state_name_abbr_to_full_name():
    # String tests
    assert hoopoe.enrich("ca", source_data_type="us_state_name_abbr", target_data_type="us_state_name_full") == "california"
    assert hoopoe.enrich("wa", source_data_type="us_state_name_abbr", target_data_type="us_state_name_full") == "washington"
    assert hoopoe.enrich("NY", source_data_type="us_state_name_abbr", target_data_type="us_state_name_full") == "new york"
    assert hoopoe.enrich("nY", source_data_type="us_state_name_abbr", target_data_type="us_state_name_full") == "new york"

    with pytest.raises(KeyError) as excinfo:
        hoopoe.enrich("n", source_data_type="us_state_name_abbr", target_data_type="us_state_name_full")
        assert "KeyError" in str(excinfo.value)

    #Dataframe tests

    # TODO: this test doesn't work. The target df is empty and so the reutned df (as expected) but the equals function returns False for some reason.
    state_abbr = [""]
    df = pd.DataFrame(state_abbr, columns={"state_abbr"})    
    target_df = pd.DataFrame()
    target_df['state_abbr'] = state_abbr
    target_df['us_state_name_full'] = [""]
    assert target_df.equals(hoopoe.enrich(df, source_data_type="us_state_name_abbr", source_data_name="state_abbr", target_data_type="us_state_name_full")) == True


    state_abbr = ["ca", "nm", "nj", "wa", "NY", "aL", "Or", "s.D", "s-c", "r  i"]
    df = pd.DataFrame(state_abbr, columns={"state_abbr"})    
    target_df = pd.DataFrame()
    target_df['state_abbr'] = state_abbr
    target_df['us_state_name_full'] = ["california", "new mexico", "new jersey", "washington", "new york", "alabama", "oregon", "south dakota", "south carolina", "rhode island"]
    assert target_df.equals(hoopoe.enrich(df, source_data_type="us_state_name_abbr", source_data_name="state_abbr", target_data_type="us_state_name_full")) == True 



def test_us_state_full_name_to_state_abbr():
    assert hoopoe.enrich("california", source_data_type="us_state_name_full", target_data_type="us_state_name_abbr") == "ca"
    assert hoopoe.enrich("washington", source_data_type="us_state_name_full", target_data_type="us_state_name_abbr") == "wa"
    assert hoopoe.enrich("New-york", source_data_type="us_state_name_full", target_data_type="us_state_name_abbr") == "ny"
    assert hoopoe.enrich("NEW jersey", source_data_type="us_state_name_full", target_data_type="us_state_name_abbr") == "nj"
    assert hoopoe.enrich("TEXAS", source_data_type="us_state_name_full", target_data_type="us_state_name_abbr") == "tx"
    assert hoopoe.enrich("NORTH CAROLINA", source_data_type="us_state_name_full", target_data_type="us_state_name_abbr") == "nc"

    with pytest.raises(KeyError) as excinfo:
        hoopoe.enrich("n", source_data_type="us_state_name_full", target_data_type="us_state_name_abbr")
        assert "KeyError" in str(excinfo.value)
    with pytest.raises(KeyError) as excinfo:
        hoopoe.enrich(" ", source_data_type="us_state_name_name", target_data_type="us_state_name_abbr")
        assert "KeyError" in str(excinfo.value)


# Temprature units
def f_to_c(df,source_data_name):
    df[source_data_name] = (df[source_data_name] - 32) * 5/9
    return df

def c_to_f(df,source_data_name):
    df[source_data_name] = df[source_data_name]* 5/9 + 32
    return df  

def c_to_k(df,source_data_name):
    df[source_data_name] = df[source_data_name] + 273.15
    return df

def k_to_c(df,source_data_name):
    df[source_data_name] = df[source_data_name] - 273.15
    return df

def k_to_f(df,source_data_name):
    df[source_data_name] = (df[source_data_name] - 273.15) * 9/5 + 32
    return df

def f_to_k(df,source_data_name):
    df[source_data_name] = (df[source_data_name] - 32) * 5/9 + 273.15
    return df

    


# string to lowercaes, remove dashse, dots and double spaces
def prepare_names(df):
    df = df.str.lower()
    df = df.str.replace('-',' ')
    df = df.str.replace('  ',' ')
    df = df.str.replace('.',' ')
    return df

def prepare_abbr(df):
    df = prepare_names(df)
    df = df.str.replace(' ', '')
    return df

def remove_plus(df):
    df = df.replace('+', '')
    return df


from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup (
    name='hoopoe',
    version='0.0.12',
    description='Hoopoe is a data enrichment service that makes it easy to improve your data-centric services and increase the accuracy of your ML models.',
    py_modules=["hoopoe", "us_states", "international_phone_prefixes", "units_conversion", "countries", "canonicalization"],
    package_dir={'': 'src'},
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
    long_description =long_description,
    long_description_content_type="text/markdown",
    install_requires=[
        #TODO: Check if can be reduced
        "pandas>=1",
    ],
    extra_requires={
        #TODO: Check if can be reduced
        "dev": [
            "pytest>=3.7",
            "check-manifest>=0.45"
        ],
    },
    url="https://github.com/delbarital/hoopoe",
    author="Tal Delbari",
    author_email="delbarital@gmail.com",
)


import us_states
# import countries
import international_phone_prefixes
import units_conversion
import canonicalization

import pandas as pd

def enrich(data, source_data_name=None, source_data_type=None, target_data_type=None):
    if source_data_name == None and source_data_type == None:
        # TODO: Make sure this is the right exception for this situation.
        raise ValueError("No source_data_name or source_data_type were provided.")
    if source_data_name == None:
        source_data_name = source_data_type
    if source_data_type == None:
        source_data_type = source_data_name
    if target_data_type == None:
        raise ValueError("No target_data_type were provided.")
 
    if isinstance(data, str):
        return str_enrich(str=data, source_data_type=source_data_type, target_data_type=target_data_type)
    if isinstance(data, (int, float, complex)):
        return str_enrich(str=str(data), source_data_type=source_data_type, target_data_type=target_data_type)
    if isinstance(data,  pd.DataFrame):
        if source_data_name==None:
            source_data_name = source_data_type
        return df_enrich(data, source_data_name, source_data_type, target_data_type)
    
def str_enrich(str, source_data_type, target_data_type):
    # We implement this function using the df_enrich. We basically send the string as a df to df_enrich
    # and later extract the answer from the df as a string and return it. 
    result_df = df_enrich(pd.DataFrame.from_dict({source_data_type: [str]}), source_data_name=source_data_type, source_data_type=source_data_type, target_data_type=target_data_type)
    result = result_df[target_data_type][0]
    if result == str:
        raise KeyError(f'The key {str} does not exist')
    return result

def df_enrich(df, source_data_name, source_data_type, target_data_type):
    # We copy the content of the original data to a new column and later replace the copied data
    # with the translated data.
    df[target_data_type] = df[source_data_name]
    if source_data_type == 'us_state_name_full' or source_data_type == 'country_name':
        df[target_data_type] = canonicalization.prepare_names(df[target_data_type])
    if source_data_type == 'us_state_name_abbr':
        df[target_data_type] = canonicalization.prepare_abbr(df[target_data_type])
    if source_data_type == 'us_state_name_abbr' and target_data_type == 'us_state_name_full':
        df = us_states.us_state_abbr_to_state_name(df, target_data_type)
    if source_data_type == 'us_state_name_full' and target_data_type == 'us_state_name_abbr':
        df = us_states.us_state_full_name_to_state_abbr(df, target_data_type)
    if source_data_type == 'us_state_name_full' and target_data_type == 'us_state_population':
        df = us_states.us_state_full_name_to_population(df, target_data_type)
    if source_data_type == 'us_state_name_full' and target_data_type == 'us_state_capital_city':
        df = us_states.us_state_full_name_to_capital_city(df, target_data_type)
    if source_data_type == 'us_state_name_full' and target_data_type == 'us_state_area_rank':
        df = us_states.us_state_full_name_to_area_rank(df, target_data_type)
    if source_data_type == 'us_capital_city_name' and target_data_type == 'us_capital_city_population':
        df = us_states.us_capital_city_population_2019(df, target_data_type)
    if source_data_type == 'us_capital_city_name' and target_data_type == 'us_capital_city_population_msa':
        df = us_states.us_capital_city_population_2019_msa(df, target_data_type)
    if source_data_type == 'us_capital_city_name' and target_data_type == 'us_capital_city_population_csa':
        df = us_states.us_capital_city_population_2019_csa(df, target_data_type)
    if source_data_name == 'us_state_name_full' and target_data_type == 'us_state_total_area_rank':
        df = us_states.us_state_total_area_rank(df, target_data_type)
    if source_data_name == 'us_state_name_full' and target_data_type == 'us_state_total_area_km':
        df = us_states.us_state_total_area(df, target_data_type)
    if source_data_name == 'us_state_name_full' and target_data_type == 'us_state_land_area_rank':
        df = us_states.us_state_land_area_rank(df, target_data_type)
    if source_data_name == 'us_state_name_full' and target_data_type == 'us_state_land_area_km':
        df = us_states.us_state_land_area(df, target_data_type)
    if source_data_name == 'us_state_name_full' and target_data_type == 'us_state_water_area_rank':
        df = us_states.us_state_water_area_rank(df, target_data_type)
    if source_data_name == 'us_state_name_full' and target_data_type == 'us_state_water_area_km':
        df = us_states.us_state_water_area(df, target_data_type)
    if source_data_type == 'int_phone_prefix' and target_data_type == 'country_name':
        df[target_data_type] = canonicalization.remove_plus(df[target_data_type])
        df = international_phone_prefixes.country_to_international_phone_prefixes(df, target_data_type)
    if source_data_type == 'country_name' and target_data_type == 'int_phone_prefix':
        df[target_data_type] = canonicalization.remove_plus(df[target_data_type])
        df = international_phone_prefixes.international_phone_prefixes_to_country(df, target_data_type)

    # if source_data_type == 'country_name' and target_data_type == 'country_population_2019':
    #     df = countries.country_population(df, target_data_type)

    if source_data_type == 'celsius' and target_data_type == 'farenheit':
        df = units_conversion.c_to_f(df, target_data_type)
    if source_data_type == 'celsius' and target_data_type == 'kelvin':
        df = units_conversion.c_to_k(df, target_data_type)
    if source_data_type == 'farenheit' and target_data_type == 'celsius':
        df = units_conversion.f_to_c(df, target_data_type)    
    if source_data_type == 'farenheit' and target_data_type == 'kelvin':
        df = units_conversion.f_to_k(df, target_data_type)    
    if source_data_type == 'kelvin' and target_data_type == 'celsius':
        df = units_conversion.k_to_c(df, target_data_type)    
    if source_data_type == 'kelvin' and target_data_type == 'farenheit':
        df = units_conversion.k_to_f(df, target_data_type)    


    return df


def international_phone_prefixes_to_country(df, source_data_name):
    df = df
    international_phone_prefixes_to_country = {
        '93':	'afghanistan',
        '355':	'albania',
        '213':	'algeria',
        '1684':	'american samoa',
        '376':	'andorra',
        '244':	'angola',
        '1264':	'anguilla',
        '672':	'antarctica',
        '1268':	'antigua and barbuda',
        '54':	'argentina',
        '374':	'armenia',
        '297':	'aruba',
        '61':	'australia \\ christmas island',
        '43':	'austria',
        '994':	'azerbaijan',
        '1242':	'bahamas',
        '973':	'bahrain',
        '880':	'bangladesh',
        '1246':	'barbados',
        '375':	'belarus',
        '32':	'belgium',
        '501':	'belize',
        '229':	'benin',
        '1441':	'bermuda',
        '975':	'bhutan',
        '591':	'bolivia',
        '387':	'bosnia and herzegovina',
        '267':	'botswana',
        '55':	'brazil',
        '246':	'british indian ocean territory',
        '1284':	'british virgin islands',
        '673':	'brunei',
        '359':	'bulgaria',
        '226':	'burkina faso',
        '257':	'burundi',
        '855':	'cambodia',
        '237':	'cameroon',
        '1':	'united states \\ canada',
        '238':	'cape verde',
        '1345':	'cayman islands',
        '236':	'central african republic',
        '235':	'chad',
        '56':	'chile',
        '86':	'china',
        '57':	'colombia',
        '269':	'comoros',
        '682':	'cook islands',
        '506':	'costa rica',
        '385':	'croatia',
        '53':	'cuba',
        '357':	'cyprus',
        '420':	'czech republic',
        '243':	'democratic republic of the congo',
        '45':	'denmark',
        '253':	'djibouti',
        '1767':	'dominica',
        '1809':	'dominican republic',
        '670':	'east timor',
        '593':	'ecuador',
        '20':	'egypt',
        '503':	'el salvador',
        '240':	'equatorial guinea',
        '291':	'eritrea',
        '372':	'estonia',
        '251':	'ethiopia',
        '500':	'falkland islands',
        '298':	'faroe islands',
        '679':	'fiji',
        '358':	'finland',
        '33':	'france',
        '689':	'french polynesia',
        '241':	'gabon',
        '220':	'gambia',
        '995':	'georgia',
        '49':	'germany',
        '233':	'ghana',
        '350':	'gibraltar',
        '30':	'greece',
        '299':	'greenland',
        '1473':	'grenada',
        '1671':	'guam',
        '502':	'guatemala',
        '441481':	'guernsey',
        '224':	'guinea',
        '245':	'guinea-bissau',
        '592':	'guyana',
        '509':	'haiti',
        '504':	'honduras',
        '852':	'hong kong',
        '36':	'hungary',
        '354':	'iceland',
        '91':	'india',
        '62':	'indonesia',
        '98':	'iran',
        '964':	'iraq',
        '353':	'ireland',
        '441624':	'isle of man',
        '972':	'israel',
        '39':	'italy',
        '225':	'ivory coast',
        '1876':	'jamaica',
        '81':	'japan',
        '441534':	'jersey',
        '962':	'jordan',
        '254':	'kenya',
        '686':	'kiribati',
        '383':	'kosovo',
        '965':	'kuwait',
        '996':	'kyrgyzstan',
        '856':	'laos',
        '371':	'latvia',
        '961':	'lebanon',
        '266':	'lesotho',
        '231':	'liberia',
        '218':	'libya',
        '423':	'liechtenstein',
        '370':	'lithuania',
        '352':	'luxembourg',
        '853':	'macau',
        '389':	'macedonia',
        '261':	'madagascar',
        '265':	'malawi',
        '60':	'malaysia',
        '960':	'maldives',
        '223':	'mali',
        '356':	'malta',
        '692':	'marshall islands',
        '222':	'mauritania',
        '230':	'mauritius',
        '52':	'mexico',
        '691':	'micronesia',
        '373':	'moldova',
        '377':	'monaco',
        '976':	'mongolia',
        '382':	'montenegro',
        '1664':	'montserrat',
        '212':	'morocco \\ western sahara',
        '258':	'mozambique',
        '95':	'myanmar',
        '264':	'namibia',
        '674':	'nauru',
        '977':	'nepal',
        '31':	'netherlands',
        '599':	'netherlands antilles \\ curacao',
        '687':	'new caledonia',
        '64':	'new zealand \\ pitcairn',
        '505':	'nicaragua',
        '227':	'niger',
        '234':	'nigeria',
        '683':	'niue',
        '850':	'north korea',
        '1670':	'northern mariana islands',
        '47':	'norway \\ svalbard and jan mayen',
        '968':	'oman',
        '92':	'pakistan',
        '680':	'palau',
        '970':	'palestine',
        '507':	'panama',
        '675':	'papua new guinea',
        '595':	'paraguay',
        '51':	'peru',
        '63':	'philippines',
        '48':	'poland',
        '351':	'portugal',
        '1787':	'puerto rico',
        '974':	'qatar',
        '242':	'republic of the congo',
        '262':	'mayotte \\ reunion',
        '40':	'romania',
        '7':	'russia \\ kazakhstan',
        '250':	'rwanda',
        '290':	'saint helena',
        '1869':	'saint kitts and nevis',
        '1758':	'saint lucia',
        '590':	'saint martin \\ saint barthelemy',
        '508':	'saint pierre and miquelon',
        '1784':	'saint vincent and the grenadines',
        '685':	'samoa',
        '378':	'san marino',
        '239':	'sao tome and principe',
        '966':	'saudi arabia',
        '221':	'senegal',
        '381':	'serbia',
        '248':	'seychelles',
        '232':	'sierra leone',
        '65':	'singapore',
        '1721':	'sint maarten',
        '421':	'slovakia',
        '386':	'slovenia',
        '677':	'solomon islands',
        '252':	'somalia',
        '27':	'south africa',
        '82':	'south korea',
        '211':	'south sudan',
        '34':	'spain',
        '94':	'sri lanka',
        '249':	'sudan',
        '597':	'suriname',
        '268':	'swaziland',
        '46':	'sweden',
        '41':	'switzerland',
        '963':	'syria',
        '886':	'taiwan',
        '992':	'tajikistan',
        '255':	'tanzania',
        '66':	'thailand',
        '228':	'togo',
        '690':	'tokelau',
        '676':	'tonga',
        '1868':	'trinidad and tobago',
        '216':	'tunisia',
        '90':	'turkey',
        '993':	'turkmenistan',
        '1649':	'turks and caicos islands',
        '688':	'tuvalu',
        '1340':	'u.s. virgin islands',
        '256':	'uganda',
        '380':	'ukraine',
        '971':	'united arab emirates',
        '44':	'united kingdom',
        '598':	'uruguay',
        '998':	'uzbekistan',
        '678':	'vanuatu',
        '379':	'vatican',
        '58':	'venezuela',
        '84':	'vietnam',
        '681':	'wallis and futuna',
        '967':	'yemen',
        '260':	'zambia',
        '263':	'zimbabwe'
    }
    df.replace({source_data_name: international_phone_prefixes_to_country}, inplace=True)
    return df

def country_to_international_phone_prefixes(df, source_data_name):
    df = df
    country_to_international_phone_prefixes = {
        'afghanistan':	'93',
        'albania':	'355',
        'algeria':	'213',
        'american samoa':	'1684',
        'andorra':	'376',
        'angola':	'244',
        'anguilla':	'1264',
        'antarctica':	'672',
        'antigua and barbuda':	'1268',
        'argentina':	'54',
        'armenia':	'374',
        'aruba':	'297',
        'australia':	'61',
        'austria':	'43',
        'azerbaijan':	'994',
        'bahamas':	'1242',
        'bahrain':	'973',
        'bangladesh':	'880',
        'barbados':	'1246',
        'belarus':	'375',
        'belgium':	'32',
        'belize':	'501',
        'benin':	'229',
        'bermuda':	'1441',
        'bhutan':	'975',
        'bolivia':	'591',
        'bosnia and herzegovina':	'387',
        'botswana':	'267',
        'brazil':	'55',
        'british indian ocean territory':	'246',
        'british virgin islands':	'1284',
        'brunei':	'673',
        'bulgaria':	'359',
        'burkina faso':	'226',
        'burundi':	'257',
        'cambodia':	'855',
        'cameroon':	'237',
        'canada':	'1',
        'cape verde':	'238',
        'cayman islands':	'1345',
        'central african republic':	'236',
        'chad':	'235',
        'chile':	'56',
        'china':	'86',
        'christmas island':	'61',
        'cocos islands':	'61',
        'colombia':	'57',
        'comoros':	'269',
        'cook islands':	'682',
        'costa rica':	'506',
        'croatia':	'385',
        'cuba':	'53',
        'curacao':	'599',
        'cyprus':	'357',
        'czech republic':	'420',
        'democratic republic of the congo':	'243',
        'denmark':	'45',
        'djibouti':	'253',
        'dominica':	'1767',
        'dominican republic':	'1809',
        'east timor':	'670',
        'ecuador':	'593',
        'egypt':	'20',
        'el salvador':	'503',
        'equatorial guinea':	'240',
        'eritrea':	'291',
        'estonia':	'372',
        'ethiopia':	'251',
        'falkland islands':	'500',
        'faroe islands':	'298',
        'fiji':	'679',
        'finland':	'358',
        'france':	'33',
        'french polynesia':	'689',
        'gabon':	'241',
        'gambia':	'220',
        'georgia':	'995',
        'germany':	'49',
        'ghana':	'233',
        'gibraltar':	'350',
        'greece':	'30',
        'greenland':	'299',
        'grenada':	'1473',
        'guam':	'1671',
        'guatemala':	'502',
        'guernsey':	'441481',
        'guinea':	'224',
        'guinea-bissau':	'245',
        'guyana':	'592',
        'haiti':	'509',
        'honduras':	'504',
        'hong kong':	'852',
        'hungary':	'36',
        'iceland':	'354',
        'india':	'91',
        'indonesia':	'62',
        'iran':	'98',
        'iraq':	'964',
        'ireland':	'353',
        'isle of man':	'441624',
        'israel':	'972',
        'italy':	'39',
        'ivory coast':	'225',
        'jamaica':	'1876',
        'japan':	'81',
        'jersey':	'441534',
        'jordan':	'962',
        'kazakhstan':	'7',
        'kenya':	'254',
        'kiribati':	'686',
        'kosovo':	'383',
        'kuwait':	'965',
        'kyrgyzstan':	'996',
        'laos':	'856',
        'latvia':	'371',
        'lebanon':	'961',
        'lesotho':	'266',
        'liberia':	'231',
        'libya':	'218',
        'liechtenstein':	'423',
        'lithuania':	'370',
        'luxembourg':	'352',
        'macau':	'853',
        'macedonia':	'389',
        'madagascar':	'261',
        'malawi':	'265',
        'malaysia':	'60',
        'maldives':	'960',
        'mali':	'223',
        'malta':	'356',
        'marshall islands':	'692',
        'mauritania':	'222',
        'mauritius':	'230',
        'mayotte':	'262',
        'mexico':	'52',
        'micronesia':	'691',
        'moldova':	'373',
        'monaco':	'377',
        'mongolia':	'976',
        'montenegro':	'382',
        'montserrat':	'1664',
        'morocco':	'212',
        'mozambique':	'258',
        'myanmar':	'95',
        'namibia':	'264',
        'nauru':	'674',
        'nepal':	'977',
        'netherlands':	'31',
        'netherlands antilles':	'599',
        'new caledonia':	'687',
        'new zealand':	'64',
        'nicaragua':	'505',
        'niger':	'227',
        'nigeria':	'234',
        'niue':	'683',
        'north korea':	'850',
        'northern mariana islands':	'1670',
        'norway':	'47',
        'oman':	'968',
        'pakistan':	'92',
        'palau':	'680',
        'palestine':	'970',
        'panama':	'507',
        'papua new guinea':	'675',
        'paraguay':	'595',
        'peru':	'51',
        'philippines':	'63',
        'pitcairn':	'64',
        'poland':	'48',
        'portugal':	'351',
        'puerto rico':	'1787',
        'qatar':	'974',
        'republic of the congo':	'242',
        'reunion':	'262',
        'romania':	'40',
        'russia':	'7',
        'rwanda':	'250',
        'saint barthelemy':	'590',
        'saint helena':	'290',
        'saint kitts and nevis':	'1869',
        'saint lucia':	'1758',
        'saint martin':	'590',
        'saint pierre and miquelon':	'508',
        'saint vincent and the grenadines':	'1784',
        'samoa':	'685',
        'san marino':	'378',
        'sao tome and principe':	'239',
        'saudi arabia':	'966',
        'senegal':	'221',
        'serbia':	'381',
        'seychelles':	'248',
        'sierra leone':	'232',
        'singapore':	'65',
        'sint maarten':	'1721',
        'slovakia':	'421',
        'slovenia':	'386',
        'solomon islands':	'677',
        'somalia':	'252',
        'south africa':	'27',
        'south korea':	'82',
        'south sudan':	'211',
        'spain':	'34',
        'sri lanka':	'94',
        'sudan':	'249',
        'suriname':	'597',
        'svalbard and jan mayen':	'47',
        'swaziland':	'268',
        'sweden':	'46',
        'switzerland':	'41',
        'syria':	'963',
        'taiwan':	'886',
        'tajikistan':	'992',
        'tanzania':	'255',
        'thailand':	'66',
        'togo':	'228',
        'tokelau':	'690',
        'tonga':	'676',
        'trinidad and tobago':	'1868',
        'tunisia':	'216',
        'turkey':	'90',
        'turkmenistan':	'993',
        'turks and caicos islands':	'1649',
        'tuvalu':	'688',
        'u.s. virgin islands':	'1340',
        'uganda':	'256',
        'ukraine':	'380',
        'united arab emirates':	'971',
        'united kingdom':	'44',
        'united states':	'1',
        'uruguay':	'598',
        'uzbekistan':	'998',
        'vanuatu':	'678',
        'vatican':	'379',
        'venezuela':	'58',
        'vietnam':	'84',
        'wallis and futuna':	'681',
        'western sahara':	'212',
        'yemen':	'967',
        'zambia':	'260',
        'zimbabwe':	'263'     
    }
    df.replace({source_data_name: country_to_international_phone_prefixes}, inplace=True)
    return df